
## Omnicloud World

It is a fleet of well-known software libraries which was been extended by cloud related methods.

Omnicloud now contains components inherited from [Plotly Dash](https://dash.plotly.com), [Pydantic](https://docs.pydantic.dev/), [Dask](https://dask.org), [Odoo](https://odoo.com), etc & own platform [Airport](https://omnicloud.world/airport).


## Value

Making software for a cloud requires two vectors business-logic & cloud integration codding.

Omnicloud components already contain cloud integration tools, so it gives developers opportunities to work with business-logic only.

<br/>


The package provide additional features for [FastAPI](https://fastapi.tiangolo.com/) and use it as a part of Omnicloud[^1]


The `omnicloud.fastapi.*` inheritance the class `fastapi.FastAPI` so all their features are available.

For fast & easy run your API you can use [Py Runner](https://omnicloud.world/runner-py/).


[^1]: Omnicloud is a fleet of tools for building, integrating and deployment to cloud application with sleeveless moving between cloud providers.
